@@ -83,7 +83,8 @@ class UITestGenerator:
         ui_tests = test_modules
         total_usage = {
             "prompt_tokens": 0,
-            "completion_tokens": 0
+            "completion_tokens": 0,
+            "total_tokens": 0
         }
         for module in ui_tests:
             for test in module["tests"]:
